#!/usr/bin/env bash

# Author: Victor Correal (victor.correal@bsc.es)
# Date  : 13/10/2023

source ../bash_utils/helpers.sh
source arg_parsing.sh

#INSTALLATION DIRs
MODEL_DIR=
SCRIPT_NAME=
OUTDIR="/gpfs/scratch/bsc32/$USER/RUNDIR/IFS-BUNDLE"
INDIR="/gpfs/projects/bsc32/DestinE/inputs"
OTHER_VAR=
IO_ENABLED=true
#Derived:
BDIR=
RAPS_DIR=
RAPS_HOST_NAME=mn5

#RESOURCES definition
NODES=DEFAULT
SLURM_SYNTAXIS_NODES=""
QUEUE=DEFAULT
SLURM_SYNTAXIS_QUEUE=""
TIME_LIMIT=DEFAULT
SLURM_SYNTAXIS_TIME_LIMIT=""
MPI_PER_NODE=DEFAULT
SLURM_SYNTAXIS_MPI_PER_NODE=""
OMP_PER_TASK=DEFAULT
SLURM_SYNTAXIS_OMP_PER_TASK=""

#SIMULATION SETUP
IO_ENABLED=false
FORCE_RUN=false
RESOLUTION=
IO_TASKS_IFS=0
IO_TASKS_NEMO=0
F_LENGHT="d5"
IO="noIO"

# parse arguments + user check(Y/N)
parse_args "$@"

# check dirs (RAPS_DIR, MODEL_DIR)
check_required_args
check_dirs

#Check configurations
case $RESOLUTION in
    tco1279-eORCA12)
        info "Running IFS+NEMO! (TCO1279-eORCA12)"
        OTHER_VAR+="--nemo-grid=eORCA12_Z75 --icmcl ICMCL_1279_1950_extra  --experiment=control --nextgemsout=0 "
        SCRIPT_NAME="hres_tco1279.eORCA12.mn5.slurm"
    ;;
    tco399-eORCA025)
        info "Running IFS+NEMO! (TCO339-eORCA025)"
        OTHER_VAR+="--nemo-grid=eORCA025_Z75 --icmcl ICMCL_399_2020 --experiment=hist "
        SCRIPT_NAME="hres_tco399.eORCA025.mn5.slurm"
    ;;
    tco79-eORCA1)
        info "Running IFS+NEMO! (TCO79-eORCA1)"
        OTHER_VAR+="--nemo-grid=eORCA1_Z75 --icmcl ICMCL_79_2020 --experiment=hist "
        SCRIPT_NAME="hres_tco79.eORCA1.mn5.slurm"
    ;;
    *)
        fatal "INVALID RESOLUTION $RESOLUTION"
    ;;
esac

#COMMON VARS:
OTHER_VAR+="--ifs-bundle-build-dir=${BDIR} "
OTHER_VAR+="--nemo --nemo-ver=V40  --nonemopart -R --deep "
OTHER_VAR+="--keepnetcdf "

#IO SETUP:
#OTHER_VAR+="--iotasks=0 --nemo-multio-server-num=0 --nextgemsout=6 --multio-write-fdb --wam-multio --ifs-multio --keepfdb"

check_submision_script
check_slurm_options
print_options

SUBMIT_DIR=$PWD
OUT_LOG="${SUBMIT_DIR}/${RESOLUTION}-${IO}-%j.out"

echo "Output log stored on: $OUT_LOG"

# SUBMIT SLURM JOB:
cd $RAPS_DIR/bin/SLURM/$RAPS_HOST_NAME

sbatch  $SLURM_SYN_NODES \
        $SLURM_SYNTAXIS_QUEUE \
        $SLURM_SYNTAXIS_TIME_LIMIT \
        $SLURM_SYNTAXIS_MPI_PER_NODE \
        $SLURM_SYNTAXIS_OMP_PER_TASK \
        --exclusive \
        --export=other="${OTHER_VAR}",fclen="${F_LENGHT}",OUTROOT="${OUTDIR}",INPROOT="${INDIR}",ALL \
        --output=$OUT_LOG $SCRIPT_NAME
